package manager;

import java.io.PrintStream;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import products.ProductInBase;

public class ProductManager
{
  private ManagementSystem manager;
  private int lastInsertedId = -1;

  public ProductManager(String paramString)
  {
    this.manager = ManagementSystem.getInstance(paramString);
  }

  public Collection getAllProducts()
  {
    ArrayList localArrayList = new ArrayList();
    try
    {
      Statement localStatement = this.manager.getConnection().createStatement();
      ResultSet localResultSet = localStatement.executeQuery("SELECT name, prot, fats, carb, gi, weight, idProd, compl, idGroup, usage FROM products ORDER BY idGroup, name");
      while (localResultSet.next())
        localArrayList.add(new ProductInBase(localResultSet.getString("name"), localResultSet.getFloat("prot"), localResultSet.getFloat("fats"), localResultSet.getFloat("carb"), localResultSet.getInt("gi"), localResultSet.getFloat("weight"), localResultSet.getInt("idProd"), localResultSet.getInt("compl") != 0, localResultSet.getInt("idGroup"), localResultSet.getInt("usage")));
      localResultSet.close();
      localStatement.close();
      this.manager.getConnection().commit();
    }
    catch (SQLException localSQLException)
    {
      localSQLException.printStackTrace();
    }
    return localArrayList;
  }

  public Collection getProductsFromGroup(int paramInt)
  {
    ArrayList localArrayList = new ArrayList();
    try
    {
      PreparedStatement localPreparedStatement;
      if (paramInt == 0)
      {
        localPreparedStatement = this.manager.getConnection().prepareStatement("SELECT name, prot, fats, carb, gi, weight, idProd, compl, idGroup, usage FROM products WHERE usage>0 ORDER BY usage DESC");
      }
      else
      {
        localPreparedStatement = this.manager.getConnection().prepareStatement("SELECT name, prot, fats, carb, gi, weight, idProd, compl, idGroup, usage FROM products WHERE idGroup=? ORDER BY name");
        localPreparedStatement.setInt(1, paramInt);
      }
      ResultSet localResultSet = localPreparedStatement.executeQuery();
      int i = 0;
      while (localResultSet.next())
      {
        if (paramInt == 0)
          ++i;
        localArrayList.add(new ProductInBase(localResultSet.getString("name"), localResultSet.getFloat("prot"), localResultSet.getFloat("fats"), localResultSet.getFloat("carb"), localResultSet.getInt("gi"), localResultSet.getFloat("weight"), localResultSet.getInt("idProd"), localResultSet.getInt("compl") != 0, localResultSet.getInt("idGroup"), localResultSet.getInt("usage")));
      }
      localResultSet.close();
      localPreparedStatement.close();
      this.manager.getConnection().commit();
    }
    catch (SQLException localSQLException)
    {
      localSQLException.printStackTrace();
    }
    return localArrayList;
  }

  public Collection addProdInBase(ProductInBase paramProductInBase)
  {
    try
    {
      PreparedStatement stmt = this.manager.getConnection().prepareStatement("INSERT INTO products (name, prot, fats, carb, gi, weight, compl, idGroup, usage) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?)");
      stmt.setString(1, paramProductInBase.getName());
      stmt.setFloat(2, paramProductInBase.getProt());
      stmt.setFloat(3, paramProductInBase.getFat());
      stmt.setFloat(4, paramProductInBase.getCarb());
      stmt.setInt(5, paramProductInBase.getGi());
      stmt.setFloat(6, paramProductInBase.getWeight());
      stmt.setInt(7, (paramProductInBase.isComplex().booleanValue()) ? 1 : 0);
      stmt.setInt(8, paramProductInBase.getOwner());
      stmt.setInt(9, paramProductInBase.getUsage());
      stmt.executeUpdate();
      stmt.close();
    }
    catch (SQLException localSQLException1)
    {
      localSQLException1.printStackTrace();
    }
    try
    {
      Statement localStatement = this.manager.getConnection().createStatement();
      ResultSet localResultSet = localStatement.executeQuery("SELECT last_insert_rowid() FROM products");
      this.lastInsertedId = -1;
      if (localResultSet.next())
        this.lastInsertedId = localResultSet.getInt(1);
      //System.out.println("product id last=" + this.lastInsertedId);
      localStatement.close();
      this.manager.getConnection().commit();
    }
    catch (SQLException localSQLException2)
    {
      localSQLException2.printStackTrace();
    }
    return getProductsFromGroup(paramProductInBase.getOwner());
  }

  public Collection addCollectionProducts(Collection paramCollection, int paramInt)
  {
    try
    {
      PreparedStatement stmt = this.manager.getConnection()
              .prepareStatement(
              "INSERT INTO products (name, prot, fats, carb, gi, weight, compl, idGroup, usage) "
              + "VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?)");
      Iterator localIterator = paramCollection.iterator();
      while (localIterator.hasNext())
      {
        Object localObject = localIterator.next();
        stmt.setString(1, ((ProductInBase)localObject).getName());
        stmt.setFloat(2, ((ProductInBase)localObject).getProt());
        stmt.setFloat(3, ((ProductInBase)localObject).getFat());
        stmt.setFloat(4, ((ProductInBase)localObject).getCarb());
        stmt.setInt(5, ((ProductInBase)localObject).getGi());
        stmt.setFloat(6, ((ProductInBase)localObject).getWeight());
        stmt.setInt(7, (((ProductInBase)localObject).isComplex().booleanValue()) ? 1 : 0);
        stmt.setInt(8, paramInt);
        stmt.setInt(9, ((ProductInBase)localObject).getUsage());

        stmt.addBatch();
        //stmt.executeUpdate();
      }
      stmt.executeBatch();
      stmt.close();
      this.manager.getConnection().commit();
    }
    catch (SQLException localSQLException)
    {
      localSQLException.printStackTrace();
    }
    return getProductsFromGroup(paramInt);
  }

  public Collection updateProductInBase(ProductInBase paramProductInBase)
  {
    try
    {
      PreparedStatement localPreparedStatement = this.manager.getConnection().prepareStatement("UPDATE products SET name=?, prot=?, fats=?, carb=?, gi=?, weight=?, compl=?, idGroup=?, usage=?WHERE idProd=?");
      localPreparedStatement.setString(1, paramProductInBase.getName());
      localPreparedStatement.setFloat(2, paramProductInBase.getProt());
      localPreparedStatement.setFloat(3, paramProductInBase.getFat());
      localPreparedStatement.setFloat(4, paramProductInBase.getCarb());
      localPreparedStatement.setInt(5, paramProductInBase.getGi());
      localPreparedStatement.setFloat(6, paramProductInBase.getWeight());
      localPreparedStatement.setInt(7, (paramProductInBase.isComplex().booleanValue()) ? 1 : 0);
      localPreparedStatement.setInt(8, paramProductInBase.getOwner());
      localPreparedStatement.setInt(9, paramProductInBase.getUsage());
      localPreparedStatement.setInt(10, paramProductInBase.getId());
      localPreparedStatement.executeUpdate();
      localPreparedStatement.close();
      this.manager.getConnection().commit();
    }
    catch (SQLException localSQLException)
    {
      localSQLException.printStackTrace();
    }
    return getProductsFromGroup(paramProductInBase.getOwner());
  }

  public Collection deleteProductFromBase(ProductInBase paramProductInBase)
  {
    if (paramProductInBase.isComplex().booleanValue())
      try
      {
        PreparedStatement localPreparedStatement1 = this.manager.getConnection().prepareStatement("DELETE FROM complex WHERE Owner=?");
        localPreparedStatement1.setInt(1, paramProductInBase.getId());
        localPreparedStatement1.executeUpdate();
        localPreparedStatement1.close();
      }
      catch (SQLException localSQLException1)
      {
        localSQLException1.printStackTrace();
      }
    try
    {
      PreparedStatement localPreparedStatement2 = this.manager.getConnection().prepareStatement("DELETE FROM products WHERE idProd=?");
      localPreparedStatement2.setInt(1, paramProductInBase.getId());
      localPreparedStatement2.executeUpdate();
      localPreparedStatement2.close();
    }
    catch (SQLException localSQLException2)
    {
      localSQLException2.printStackTrace();
    }
    try
    {
      this.manager.getConnection().commit();
    }
    catch (SQLException localSQLException3)
    {
      localSQLException3.printStackTrace();
    }
    return getProductsFromGroup(paramProductInBase.getOwner());
  }

  public int getLastInsertedId()
  {
    return this.lastInsertedId;
  }
}

/* Location:           /home/connie/Documents/to_send/Importer/Importer.jar
 * Qualified Name:     manager.ProductManager
 * JD-Core Version:    0.5.3
 */